Forma36Icons class

Class containing Forma 36 icons.

This font was generated by FlutterIcon.com.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

arrow_down → const IconData
Icon data for 'arrow_down' glyph.
arrowbackward → const IconData
Icon data for 'arrowbackward' glyph.
arrowforward → const IconData
Icon data for 'arrowforward' glyph.
arrowup → const IconData
Icon data for 'arrowup' glyph.
asset → const IconData
Icon data for 'asset' glyph.
bin → const IconData
Icon data for 'bin' glyph.
calendar → const IconData
Icon data for 'calendar' glyph.
chatbubble → const IconData
Icon data for 'chatbubble' glyph.
checkcircle → const IconData
Icon data for 'checkcircle' glyph.
checkmark → const IconData
Icon data for 'checkmark' glyph.
chevron_down → const IconData
Icon data for 'chevron_down' glyph.
chevron_left → const IconData
Icon data for 'chevron_left' glyph.
chevron_right → const IconData
Icon data for 'chevron_right' glyph.
chevron_up → const IconData
Icon data for 'chevron_up' glyph.
close → const IconData
Icon data for 'close' glyph.
code → const IconData
Icon data for 'code' glyph.
copy → const IconData
Icon data for 'copy' glyph.
cycle → const IconData
Icon data for 'cycle' glyph.
delete → const IconData
Icon data for 'delete' glyph.
download → const IconData
Icon data for 'download' glyph.
drag → const IconData
Icon data for 'drag' glyph.
edit → const IconData
Icon data for 'edit' glyph.
entry → const IconData
Icon data for 'entry' glyph.
error_circle_outline → const IconData
Icon data for 'error_circle_outline' glyph.
errorcircle → const IconData
Icon data for 'errorcircle' glyph.
Icon data for 'external_link' glyph.
eye → const IconData
Icon data for 'eye' glyph.
face_happy → const IconData
Icon data for 'face_happy' glyph.
filter → const IconData
Icon data for 'filter' glyph.
folder → const IconData
Icon data for 'folder' glyph.
folder_create → const IconData
Icon data for 'folder_create' glyph.
folder_open → const IconData
Icon data for 'folder_open' glyph.
format_bold → const IconData
Icon data for 'format_bold' glyph.
format_italic → const IconData
Icon data for 'format_italic' glyph.
format_underlined → const IconData
Icon data for 'format_underlined' glyph.
heading → const IconData
Icon data for 'heading' glyph.
heading_one → const IconData
Icon data for 'heading_one' glyph.
heading_two → const IconData
Icon data for 'heading_two' glyph.
help_circle → const IconData
Icon data for 'help_circle' glyph.
horizontal_rule → const IconData
Icon data for 'horizontal_rule' glyph.
infocircle → const IconData
Icon data for 'infocircle' glyph.
Icon data for 'link' glyph.
list_bulleted → const IconData
Icon data for 'list_bulleted' glyph.
list_numbered → const IconData
Icon data for 'list_numbered' glyph.
loading → const IconData
Icon data for 'loading' glyph.
lock → const IconData
Icon data for 'lock' glyph.
logout → const IconData
Icon data for 'logout' glyph.
Icon data for 'menu' glyph.
more → const IconData
Icon data for 'more' glyph.
more_horizontal → const IconData
Icon data for 'more_horizontal' glyph.
more_vertical → const IconData
Icon data for 'more_vertical' glyph.
plus → const IconData
Icon data for 'plus' glyph.
plus_circle → const IconData
Icon data for 'plus_circle' glyph.
puzzle → const IconData
Icon data for 'puzzle' glyph.
quote → const IconData
Icon data for 'quote' glyph.
receipt → const IconData
Icon data for 'receipt' glyph.
reference → const IconData
Icon data for 'reference' glyph.
resize → const IconData
Icon data for 'resize' glyph.
Icon data for 'search' glyph.
settings → const IconData
Icon data for 'settings' glyph.
shopping_cart → const IconData
Icon data for 'shopping_cart' glyph.
star → const IconData
Icon data for 'star' glyph.
text → const IconData
Icon data for 'text' glyph.
thumb_down → const IconData
Icon data for 'thumb_down' glyph.
thumb_up → const IconData
Icon data for 'thumb_up' glyph.
toggle → const IconData
Icon data for 'toggle' glyph.
triangleoutline → const IconData
Icon data for 'triangleoutline' glyph.
users → const IconData
Icon data for 'users' glyph.
warning → const IconData
Icon data for 'warning' glyph.